# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'GUI/filter_gui.ui'
#
# Created by: PyQt5 UI code generator 5.15.10
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Filter_Dialog(object):
    def setupUi(self, Filter_Dialog):
        Filter_Dialog.setObjectName("Filter_Dialog")
        Filter_Dialog.resize(623, 386)
        self.gridLayout = QtWidgets.QGridLayout(Filter_Dialog)
        self.gridLayout.setObjectName("gridLayout")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem)
        self.label = QtWidgets.QLabel(Filter_Dialog)
        font = QtGui.QFont()
        font.setPointSize(14)
        self.label.setFont(font)
        self.label.setObjectName("label")
        self.horizontalLayout.addWidget(self.label)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem1)
        self.gridLayout.addLayout(self.horizontalLayout, 0, 0, 1, 1)
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.gridLayout.addLayout(self.verticalLayout, 1, 0, 1, 1)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.toggle_selected_button = QtWidgets.QPushButton(Filter_Dialog)
        self.toggle_selected_button.setObjectName("toggle_selected_button")
        self.horizontalLayout_2.addWidget(self.toggle_selected_button)
        self.select_all_button = QtWidgets.QPushButton(Filter_Dialog)
        self.select_all_button.setObjectName("select_all_button")
        self.horizontalLayout_2.addWidget(self.select_all_button)
        self.deselect_all_button = QtWidgets.QPushButton(Filter_Dialog)
        self.deselect_all_button.setObjectName("deselect_all_button")
        self.horizontalLayout_2.addWidget(self.deselect_all_button)
        self.apply_button = QtWidgets.QPushButton(Filter_Dialog)
        self.apply_button.setObjectName("apply_button")
        self.horizontalLayout_2.addWidget(self.apply_button)
        self.gridLayout.addLayout(self.horizontalLayout_2, 2, 0, 1, 1)

        self.retranslateUi(Filter_Dialog)
        QtCore.QMetaObject.connectSlotsByName(Filter_Dialog)

    def retranslateUi(self, Filter_Dialog):
        _translate = QtCore.QCoreApplication.translate
        Filter_Dialog.setWindowTitle(_translate("Filter_Dialog", "Dialog"))
        self.label.setText(_translate("Filter_Dialog", "Select the XRD diffractograms to be plotted"))
        self.toggle_selected_button.setText(_translate("Filter_Dialog", "Toggle Selected"))
        self.select_all_button.setText(_translate("Filter_Dialog", "Select All"))
        self.deselect_all_button.setText(_translate("Filter_Dialog", "Deselect All"))
        self.apply_button.setText(_translate("Filter_Dialog", "Apply Filter"))
