# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'GUI/iguape_gui.ui'
#
# Created by: PyQt5 UI code generator 5.15.10
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(1160, 749)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap("GUI/../../../.designer/backup/Icons/Logo_IGUAPE.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        MainWindow.setWindowIcon(icon)
        MainWindow.setStyleSheet("")
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.centralwidget)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.CNPEM_logo = QtWidgets.QLabel(self.centralwidget)
        self.CNPEM_logo.setMaximumSize(QtCore.QSize(100, 50))
        self.CNPEM_logo.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))
        self.CNPEM_logo.setText("")
        self.CNPEM_logo.setPixmap(QtGui.QPixmap("GUI/../Icons/CNPEM-logo-colorido-2023_resize.png"))
        self.CNPEM_logo.setOpenExternalLinks(True)
        self.CNPEM_logo.setObjectName("CNPEM_logo")
        self.horizontalLayout.addWidget(self.CNPEM_logo)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem)
        self.iguape_logo = QtWidgets.QLabel(self.centralwidget)
        self.iguape_logo.setMaximumSize(QtCore.QSize(100, 70))
        self.iguape_logo.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))
        self.iguape_logo.setText("")
        self.iguape_logo.setPixmap(QtGui.QPixmap("GUI/../Icons/Logo_IGUAPE_resized.png"))
        self.iguape_logo.setOpenExternalLinks(True)
        self.iguape_logo.setObjectName("iguape_logo")
        self.horizontalLayout.addWidget(self.iguape_logo)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem1)
        self.title_label = QtWidgets.QLabel(self.centralwidget)
        self.title_label.setMinimumSize(QtCore.QSize(0, 0))
        self.title_label.setMaximumSize(QtCore.QSize(16777215, 50))
        font = QtGui.QFont()
        font.setPointSize(14)
        self.title_label.setFont(font)
        self.title_label.setFrameShape(QtWidgets.QFrame.HLine)
        self.title_label.setFrameShadow(QtWidgets.QFrame.Raised)
        self.title_label.setLineWidth(1)
        self.title_label.setAlignment(QtCore.Qt.AlignCenter)
        self.title_label.setObjectName("title_label")
        self.horizontalLayout.addWidget(self.title_label)
        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem2)
        self.LNLS_logo = QtWidgets.QLabel(self.centralwidget)
        self.LNLS_logo.setMaximumSize(QtCore.QSize(16777215, 50))
        self.LNLS_logo.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))
        self.LNLS_logo.setText("")
        self.LNLS_logo.setPixmap(QtGui.QPixmap("GUI/../Icons/LNLS_logo_resize.png"))
        self.LNLS_logo.setAlignment(QtCore.Qt.AlignCenter)
        self.LNLS_logo.setObjectName("LNLS_logo")
        self.horizontalLayout.addWidget(self.LNLS_logo)
        spacerItem3 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem3)
        self.paineira_logo = QtWidgets.QLabel(self.centralwidget)
        self.paineira_logo.setMaximumSize(QtCore.QSize(70, 100))
        self.paineira_logo.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))
        self.paineira_logo.setPixmap(QtGui.QPixmap("GUI/../Icons/Paineira_resize.png"))
        self.paineira_logo.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.paineira_logo.setObjectName("paineira_logo")
        self.horizontalLayout.addWidget(self.paineira_logo)
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.tabWidget = QtWidgets.QTabWidget(self.centralwidget)
        self.tabWidget.setMinimumSize(QtCore.QSize(900, 400))
        font = QtGui.QFont()
        font.setPointSize(16)
        self.tabWidget.setFont(font)
        self.tabWidget.setObjectName("tabWidget")
        self.XRD_data_tab = QtWidgets.QWidget()
        self.XRD_data_tab.setObjectName("XRD_data_tab")
        self.gridLayout_4 = QtWidgets.QGridLayout(self.XRD_data_tab)
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.XRD_data_layout = QtWidgets.QVBoxLayout()
        self.XRD_data_layout.setObjectName("XRD_data_layout")
        self.gridLayout_4.addLayout(self.XRD_data_layout, 0, 0, 1, 1)
        self.groupBox = QtWidgets.QGroupBox(self.XRD_data_tab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox.sizePolicy().hasHeightForWidth())
        self.groupBox.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(16)
        self.groupBox.setFont(font)
        self.groupBox.setObjectName("groupBox")
        self.gridLayout = QtWidgets.QGridLayout(self.groupBox)
        self.gridLayout.setObjectName("gridLayout")
        self.horizontalLayout_9 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_9.setObjectName("horizontalLayout_9")
        self.offset_label = QtWidgets.QLabel(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.offset_label.sizePolicy().hasHeightForWidth())
        self.offset_label.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(14)
        self.offset_label.setFont(font)
        self.offset_label.setObjectName("offset_label")
        self.horizontalLayout_9.addWidget(self.offset_label)
        self.offset_slider = QtWidgets.QSlider(self.groupBox)
        self.offset_slider.setMaximumSize(QtCore.QSize(500, 16777215))
        font = QtGui.QFont()
        font.setPointSize(16)
        self.offset_slider.setFont(font)
        self.offset_slider.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.offset_slider.setMinimum(1)
        self.offset_slider.setOrientation(QtCore.Qt.Horizontal)
        self.offset_slider.setInvertedAppearance(False)
        self.offset_slider.setInvertedControls(False)
        self.offset_slider.setObjectName("offset_slider")
        self.horizontalLayout_9.addWidget(self.offset_slider)
        self.label_5 = QtWidgets.QLabel(self.groupBox)
        self.label_5.setObjectName("label_5")
        self.horizontalLayout_9.addWidget(self.label_5)
        self.color_pallete_comboBox_2 = QtWidgets.QComboBox(self.groupBox)
        self.color_pallete_comboBox_2.setObjectName("color_pallete_comboBox_2")
        self.horizontalLayout_9.addWidget(self.color_pallete_comboBox_2)
        self.gridLayout.addLayout(self.horizontalLayout_9, 0, 0, 1, 1)
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.refresh_button = QtWidgets.QPushButton(self.groupBox)
        self.refresh_button.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setPointSize(14)
        self.refresh_button.setFont(font)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap("GUI/../../../.designer/backup/Icons/Refresh_Icon.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.refresh_button.setIcon(icon1)
        self.refresh_button.setObjectName("refresh_button")
        self.horizontalLayout_6.addWidget(self.refresh_button)
        self.reset_button = QtWidgets.QPushButton(self.groupBox)
        self.reset_button.setMinimumSize(QtCore.QSize(0, 0))
        self.reset_button.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setPointSize(14)
        self.reset_button.setFont(font)
        self.reset_button.setObjectName("reset_button")
        self.horizontalLayout_6.addWidget(self.reset_button)
        self.gridLayout.addLayout(self.horizontalLayout_6, 0, 1, 1, 1)
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.index_label = QtWidgets.QLabel(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.index_label.sizePolicy().hasHeightForWidth())
        self.index_label.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(14)
        self.index_label.setFont(font)
        self.index_label.setObjectName("index_label")
        self.horizontalLayout_7.addWidget(self.index_label)
        self.XRD_measure_order_checkbox = QtWidgets.QCheckBox(self.groupBox)
        self.XRD_measure_order_checkbox.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setPointSize(14)
        self.XRD_measure_order_checkbox.setFont(font)
        self.XRD_measure_order_checkbox.setCheckable(True)
        self.XRD_measure_order_checkbox.setChecked(True)
        self.XRD_measure_order_checkbox.setTristate(False)
        self.XRD_measure_order_checkbox.setObjectName("XRD_measure_order_checkbox")
        self.horizontalLayout_7.addWidget(self.XRD_measure_order_checkbox)
        self.temperature_checkbox = QtWidgets.QCheckBox(self.groupBox)
        self.temperature_checkbox.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setPointSize(14)
        self.temperature_checkbox.setFont(font)
        self.temperature_checkbox.setObjectName("temperature_checkbox")
        self.horizontalLayout_7.addWidget(self.temperature_checkbox)
        self.gridLayout.addLayout(self.horizontalLayout_7, 1, 0, 1, 1)
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_8.setObjectName("horizontalLayout_8")
        self.checkBox = QtWidgets.QCheckBox(self.groupBox)
        self.checkBox.setObjectName("checkBox")
        self.horizontalLayout_8.addWidget(self.checkBox)
        self.min_filter_label = QtWidgets.QLabel(self.groupBox)
        self.min_filter_label.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setPointSize(14)
        self.min_filter_label.setFont(font)
        self.min_filter_label.setObjectName("min_filter_label")
        self.horizontalLayout_8.addWidget(self.min_filter_label)
        self.min_temp_doubleSpinBox = QtWidgets.QDoubleSpinBox(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.min_temp_doubleSpinBox.sizePolicy().hasHeightForWidth())
        self.min_temp_doubleSpinBox.setSizePolicy(sizePolicy)
        self.min_temp_doubleSpinBox.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setPointSize(14)
        self.min_temp_doubleSpinBox.setFont(font)
        self.min_temp_doubleSpinBox.setReadOnly(True)
        self.min_temp_doubleSpinBox.setDecimals(0)
        self.min_temp_doubleSpinBox.setObjectName("min_temp_doubleSpinBox")
        self.horizontalLayout_8.addWidget(self.min_temp_doubleSpinBox)
        self.max_filter_label = QtWidgets.QLabel(self.groupBox)
        self.max_filter_label.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setPointSize(14)
        self.max_filter_label.setFont(font)
        self.max_filter_label.setObjectName("max_filter_label")
        self.horizontalLayout_8.addWidget(self.max_filter_label)
        self.max_temp_doubleSpinBox = QtWidgets.QDoubleSpinBox(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.max_temp_doubleSpinBox.sizePolicy().hasHeightForWidth())
        self.max_temp_doubleSpinBox.setSizePolicy(sizePolicy)
        self.max_temp_doubleSpinBox.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setPointSize(14)
        self.max_temp_doubleSpinBox.setFont(font)
        self.max_temp_doubleSpinBox.setFrame(True)
        self.max_temp_doubleSpinBox.setReadOnly(True)
        self.max_temp_doubleSpinBox.setDecimals(0)
        self.max_temp_doubleSpinBox.setObjectName("max_temp_doubleSpinBox")
        self.horizontalLayout_8.addWidget(self.max_temp_doubleSpinBox)
        self.filter_button = QtWidgets.QPushButton(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.filter_button.sizePolicy().hasHeightForWidth())
        self.filter_button.setSizePolicy(sizePolicy)
        self.filter_button.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setPointSize(14)
        self.filter_button.setFont(font)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap("GUI/../../../.designer/backup/Icons/Filter_Icon.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.filter_button.setIcon(icon2)
        self.filter_button.setObjectName("filter_button")
        self.horizontalLayout_8.addWidget(self.filter_button)
        self.gridLayout.addLayout(self.horizontalLayout_8, 1, 1, 1, 1)
        self.gridLayout_4.addWidget(self.groupBox, 1, 0, 1, 1)
        self.tabWidget.addTab(self.XRD_data_tab, "")
        self.peak_fit_tab = QtWidgets.QWidget()
        self.peak_fit_tab.setObjectName("peak_fit_tab")
        self.gridLayout_5 = QtWidgets.QGridLayout(self.peak_fit_tab)
        self.gridLayout_5.setObjectName("gridLayout_5")
        self.peak_fit_layout = QtWidgets.QVBoxLayout()
        self.peak_fit_layout.setObjectName("peak_fit_layout")
        self.gridLayout_5.addLayout(self.peak_fit_layout, 0, 0, 1, 1)
        self.groupBox_3 = QtWidgets.QGroupBox(self.peak_fit_tab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_3.sizePolicy().hasHeightForWidth())
        self.groupBox_3.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(16)
        self.groupBox_3.setFont(font)
        self.groupBox_3.setObjectName("groupBox_3")
        self.gridLayout_8 = QtWidgets.QGridLayout(self.groupBox_3)
        self.gridLayout_8.setObjectName("gridLayout_8")
        self.save_peak_fit_data_button = QtWidgets.QPushButton(self.groupBox_3)
        self.save_peak_fit_data_button.setMinimumSize(QtCore.QSize(0, 0))
        self.save_peak_fit_data_button.setMaximumSize(QtCore.QSize(16777215, 16777215))
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap("GUI/../../../.designer/backup/Icons/Save_Icon.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.save_peak_fit_data_button.setIcon(icon3)
        self.save_peak_fit_data_button.setObjectName("save_peak_fit_data_button")
        self.gridLayout_8.addWidget(self.save_peak_fit_data_button, 0, 2, 1, 1)
        self.refresh_button_peak_fit = QtWidgets.QPushButton(self.groupBox_3)
        self.refresh_button_peak_fit.setObjectName("refresh_button_peak_fit")
        self.gridLayout_8.addWidget(self.refresh_button_peak_fit, 0, 0, 1, 1)
        self.peak_fit_button = QtWidgets.QPushButton(self.groupBox_3)
        self.peak_fit_button.setMaximumSize(QtCore.QSize(16777215, 16777215))
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap("GUI/../../../.designer/backup/Icons/peak_fit_icon.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.peak_fit_button.setIcon(icon4)
        self.peak_fit_button.setObjectName("peak_fit_button")
        self.gridLayout_8.addWidget(self.peak_fit_button, 0, 1, 1, 1)
        self.gridLayout_5.addWidget(self.groupBox_3, 1, 0, 1, 1)
        self.tabWidget.addTab(self.peak_fit_tab, "")
        self.contour_tab = QtWidgets.QWidget()
        self.contour_tab.setObjectName("contour_tab")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.contour_tab)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.contour_layout = QtWidgets.QVBoxLayout()
        self.contour_layout.setObjectName("contour_layout")
        self.gridLayout_2.addLayout(self.contour_layout, 0, 0, 1, 1)
        self.groupBox_2 = QtWidgets.QGroupBox(self.contour_tab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_2.sizePolicy().hasHeightForWidth())
        self.groupBox_2.setSizePolicy(sizePolicy)
        self.groupBox_2.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.groupBox_2.setObjectName("groupBox_2")
        self.gridLayout_6 = QtWidgets.QGridLayout(self.groupBox_2)
        self.gridLayout_6.setObjectName("gridLayout_6")
        self.label_3 = QtWidgets.QLabel(self.groupBox_2)
        self.label_3.setObjectName("label_3")
        self.gridLayout_6.addWidget(self.label_3, 0, 0, 1, 1)
        self.norm_comboBox = QtWidgets.QComboBox(self.groupBox_2)
        self.norm_comboBox.setObjectName("norm_comboBox")
        self.norm_comboBox.addItem("")
        self.norm_comboBox.addItem("")
        self.norm_comboBox.addItem("")
        self.gridLayout_6.addWidget(self.norm_comboBox, 0, 1, 1, 1)
        self.label_4 = QtWidgets.QLabel(self.groupBox_2)
        self.label_4.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.label_4.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_4.setObjectName("label_4")
        self.gridLayout_6.addWidget(self.label_4, 0, 2, 1, 1)
        self.color_pallete_comboBox = QtWidgets.QComboBox(self.groupBox_2)
        self.color_pallete_comboBox.setObjectName("color_pallete_comboBox")
        self.gridLayout_6.addWidget(self.color_pallete_comboBox, 0, 3, 1, 1)
        self.contour_button = QtWidgets.QPushButton(self.groupBox_2)
        self.contour_button.setObjectName("contour_button")
        self.gridLayout_6.addWidget(self.contour_button, 0, 4, 1, 1)
        self.gridLayout_2.addWidget(self.groupBox_2, 1, 0, 1, 1)
        self.tabWidget.addTab(self.contour_tab, "")
        self.normalization_tab = QtWidgets.QWidget()
        self.normalization_tab.setObjectName("normalization_tab")
        self.gridLayout_7 = QtWidgets.QGridLayout(self.normalization_tab)
        self.gridLayout_7.setObjectName("gridLayout_7")
        self.normalization_layout = QtWidgets.QVBoxLayout()
        self.normalization_layout.setObjectName("normalization_layout")
        self.gridLayout_7.addLayout(self.normalization_layout, 0, 0, 1, 1)
        self.groupBox_4 = QtWidgets.QGroupBox(self.normalization_tab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_4.sizePolicy().hasHeightForWidth())
        self.groupBox_4.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(16)
        self.groupBox_4.setFont(font)
        self.groupBox_4.setObjectName("groupBox_4")
        self.gridLayout_9 = QtWidgets.QGridLayout(self.groupBox_4)
        self.gridLayout_9.setObjectName("gridLayout_9")
        self.label = QtWidgets.QLabel(self.groupBox_4)
        self.label.setObjectName("label")
        self.gridLayout_9.addWidget(self.label, 0, 0, 1, 1)
        self.norm_offset_slider = QtWidgets.QSlider(self.groupBox_4)
        self.norm_offset_slider.setMinimum(1)
        self.norm_offset_slider.setProperty("value", 70)
        self.norm_offset_slider.setOrientation(QtCore.Qt.Horizontal)
        self.norm_offset_slider.setObjectName("norm_offset_slider")
        self.gridLayout_9.addWidget(self.norm_offset_slider, 0, 1, 1, 1)
        self.normalize_button = QtWidgets.QPushButton(self.groupBox_4)
        font = QtGui.QFont()
        font.setPointSize(14)
        self.normalize_button.setFont(font)
        self.normalize_button.setObjectName("normalize_button")
        self.gridLayout_9.addWidget(self.normalize_button, 0, 2, 1, 1)
        self.gridLayout_7.addWidget(self.groupBox_4, 1, 0, 1, 1)
        self.tabWidget.addTab(self.normalization_tab, "")
        self.verticalLayout.addWidget(self.tabWidget)
        self.gridLayout_3.addLayout(self.verticalLayout, 0, 0, 1, 1)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 1160, 20))
        self.menubar.setObjectName("menubar")
        self.menuFolder = QtWidgets.QMenu(self.menubar)
        self.menuFolder.setObjectName("menuFolder")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.actionOpen_New_Folder = QtWidgets.QAction(MainWindow)
        self.actionOpen_New_Folder.setObjectName("actionOpen_New_Folder")
        self.actionAbout = QtWidgets.QAction(MainWindow)
        self.actionAbout.setObjectName("actionAbout")
        self.actionHelp = QtWidgets.QAction(MainWindow)
        self.actionHelp.setObjectName("actionHelp")
        self.actionExport_Figure = QtWidgets.QAction(MainWindow)
        self.actionExport_Figure.setObjectName("actionExport_Figure")
        self.menuFolder.addAction(self.actionOpen_New_Folder)
        self.menuFolder.addAction(self.actionExport_Figure)
        self.menuFolder.addSeparator()
        self.menuFolder.addAction(self.actionAbout)
        self.menuFolder.addAction(self.actionHelp)
        self.menubar.addAction(self.menuFolder.menuAction())

        self.retranslateUi(MainWindow)
        self.tabWidget.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "Iguape"))
        self.title_label.setText(_translate("MainWindow", "<html><head/><body><p align=\"center\"><span style=\" font-weight:600;\">IGUAPE</span></p><p align=\"center\"><span style=\" font-size:7pt; font-weight:600;\">(PAINEIRA GRAPHICAL USER INTERFACE)</span></p></body></html>"))
        self.groupBox.setTitle(_translate("MainWindow", "Tools"))
        self.offset_label.setText(_translate("MainWindow", "XRD patterns offset:"))
        self.offset_slider.setToolTip(_translate("MainWindow", "Select the XRD patterns offset"))
        self.label_5.setText(_translate("MainWindow", "Color Palette"))
        self.refresh_button.setToolTip(_translate("MainWindow", "Press to refresh the graph with the new XRD patterns"))
        self.refresh_button.setText(_translate("MainWindow", "Refresh"))
        self.reset_button.setToolTip(_translate("MainWindow", "Press to reset the 2θ interval to the deafult range"))
        self.reset_button.setText(_translate("MainWindow", "Reset 2θ"))
        self.index_label.setText(_translate("MainWindow", "XDR patterns indexing:"))
        self.XRD_measure_order_checkbox.setText(_translate("MainWindow", "XRD acquisition time"))
        self.temperature_checkbox.setText(_translate("MainWindow", "Temperature"))
        self.checkBox.setText(_translate("MainWindow", "VLine"))
        self.min_filter_label.setText(_translate("MainWindow", "Minimum"))
        self.max_filter_label.setText(_translate("MainWindow", "Maximum"))
        self.filter_button.setToolTip(_translate("MainWindow", "Press to apply the temperature/measure order range"))
        self.filter_button.setText(_translate("MainWindow", "Apply Filter "))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.XRD_data_tab), _translate("MainWindow", "XRD Data"))
        self.groupBox_3.setTitle(_translate("MainWindow", "Tools"))
        self.save_peak_fit_data_button.setToolTip(_translate("MainWindow", "Press to save the data as a CSV file"))
        self.save_peak_fit_data_button.setText(_translate("MainWindow", "Save Peak Fit Data"))
        self.refresh_button_peak_fit.setText(_translate("MainWindow", "Refresh"))
        self.peak_fit_button.setToolTip(_translate("MainWindow", "Press to open the Peak Fit Window"))
        self.peak_fit_button.setText(_translate("MainWindow", "Peak Fit"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.peak_fit_tab), _translate("MainWindow", "Peak Fitting"))
        self.groupBox_2.setTitle(_translate("MainWindow", "Tools"))
        self.label_3.setText(_translate("MainWindow", "Contour Norm"))
        self.norm_comboBox.setItemText(0, _translate("MainWindow", "LogNorm"))
        self.norm_comboBox.setItemText(1, _translate("MainWindow", "PowerNorm"))
        self.norm_comboBox.setItemText(2, _translate("MainWindow", "CenteredNorm"))
        self.label_4.setText(_translate("MainWindow", "Color Palette"))
        self.contour_button.setText(_translate("MainWindow", "Generate Contour"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.contour_tab), _translate("MainWindow", "Contour Plot"))
        self.groupBox_4.setTitle(_translate("MainWindow", "Tools"))
        self.label.setText(_translate("MainWindow", "XRD patterns offset:"))
        self.normalize_button.setText(_translate("MainWindow", "Generate Normalization Plot"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.normalization_tab), _translate("MainWindow", "Normalization"))
        self.menuFolder.setTitle(_translate("MainWindow", "Folder"))
        self.actionOpen_New_Folder.setText(_translate("MainWindow", "Open New Folder"))
        self.actionAbout.setText(_translate("MainWindow", "About"))
        self.actionHelp.setText(_translate("MainWindow", "Help"))
        self.actionExport_Figure.setText(_translate("MainWindow", "Export Figure"))
