# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'GUI/export_figure.ui'
#
# Created by: PyQt5 UI code generator 5.15.10
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Export_Figure(object):
    def setupUi(self, Export_Figure):
        Export_Figure.setObjectName("Export_Figure")
        Export_Figure.resize(917, 692)
        self.gridLayout = QtWidgets.QGridLayout(Export_Figure)
        self.gridLayout.setObjectName("gridLayout")
        self.frame = QtWidgets.QFrame(Export_Figure)
        self.frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame.setObjectName("frame")
        self.gridLayout_4 = QtWidgets.QGridLayout(self.frame)
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.groupBox = QtWidgets.QGroupBox(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox.sizePolicy().hasHeightForWidth())
        self.groupBox.setSizePolicy(sizePolicy)
        self.groupBox.setMaximumSize(QtCore.QSize(16777215, 250))
        font = QtGui.QFont()
        font.setPointSize(11)
        self.groupBox.setFont(font)
        self.groupBox.setObjectName("groupBox")
        self.gridLayout_5 = QtWidgets.QGridLayout(self.groupBox)
        self.gridLayout_5.setObjectName("gridLayout_5")
        self.label_6 = QtWidgets.QLabel(self.groupBox)
        self.label_6.setObjectName("label_6")
        self.gridLayout_5.addWidget(self.label_6, 1, 1, 1, 1)
        self.gridLayout_3 = QtWidgets.QGridLayout()
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.save_fig_button = QtWidgets.QPushButton(self.groupBox)
        self.save_fig_button.setObjectName("save_fig_button")
        self.gridLayout_3.addWidget(self.save_fig_button, 1, 2, 3, 2)
        self.redraw_button = QtWidgets.QPushButton(self.groupBox)
        self.redraw_button.setObjectName("redraw_button")
        self.gridLayout_3.addWidget(self.redraw_button, 0, 2, 1, 1)
        self.format_comboBox = QtWidgets.QComboBox(self.groupBox)
        self.format_comboBox.setObjectName("format_comboBox")
        self.format_comboBox.addItem("")
        self.format_comboBox.addItem("")
        self.format_comboBox.addItem("")
        self.format_comboBox.addItem("")
        self.gridLayout_3.addWidget(self.format_comboBox, 0, 1, 1, 1)
        self.format_label = QtWidgets.QLabel(self.groupBox)
        self.format_label.setObjectName("format_label")
        self.gridLayout_3.addWidget(self.format_label, 0, 0, 1, 1)
        self.label_12 = QtWidgets.QLabel(self.groupBox)
        self.label_12.setObjectName("label_12")
        self.gridLayout_3.addWidget(self.label_12, 1, 0, 1, 1)
        self.dpi_spinBox = QtWidgets.QSpinBox(self.groupBox)
        self.dpi_spinBox.setMinimum(1)
        self.dpi_spinBox.setMaximum(999999999)
        self.dpi_spinBox.setObjectName("dpi_spinBox")
        self.gridLayout_3.addWidget(self.dpi_spinBox, 1, 1, 1, 1)
        self.gridLayout_5.addLayout(self.gridLayout_3, 4, 4, 3, 1)
        self.gridLayout_2 = QtWidgets.QGridLayout()
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.label_5 = QtWidgets.QLabel(self.groupBox)
        self.label_5.setObjectName("label_5")
        self.gridLayout_2.addWidget(self.label_5, 1, 1, 1, 1)
        self.label_4 = QtWidgets.QLabel(self.groupBox)
        self.label_4.setObjectName("label_4")
        self.gridLayout_2.addWidget(self.label_4, 0, 0, 2, 1)
        self.label_3 = QtWidgets.QLabel(self.groupBox)
        self.label_3.setObjectName("label_3")
        self.gridLayout_2.addWidget(self.label_3, 0, 1, 1, 1)
        self.height_doubleSpinBox = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.height_doubleSpinBox.setLocale(QtCore.QLocale(QtCore.QLocale.English, QtCore.QLocale.UnitedKingdom))
        self.height_doubleSpinBox.setDecimals(1)
        self.height_doubleSpinBox.setMinimum(1.0)
        self.height_doubleSpinBox.setMaximum(100.0)
        self.height_doubleSpinBox.setSingleStep(0.1)
        self.height_doubleSpinBox.setProperty("value", 8.0)
        self.height_doubleSpinBox.setObjectName("height_doubleSpinBox")
        self.gridLayout_2.addWidget(self.height_doubleSpinBox, 0, 2, 1, 1)
        self.width_doubleSpinBox = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.width_doubleSpinBox.setLocale(QtCore.QLocale(QtCore.QLocale.English, QtCore.QLocale.UnitedKingdom))
        self.width_doubleSpinBox.setDecimals(1)
        self.width_doubleSpinBox.setMinimum(1.0)
        self.width_doubleSpinBox.setSingleStep(0.1)
        self.width_doubleSpinBox.setStepType(QtWidgets.QAbstractSpinBox.DefaultStepType)
        self.width_doubleSpinBox.setProperty("value", 8.0)
        self.width_doubleSpinBox.setObjectName("width_doubleSpinBox")
        self.gridLayout_2.addWidget(self.width_doubleSpinBox, 1, 2, 1, 1)
        self.gridLayout_5.addLayout(self.gridLayout_2, 4, 0, 3, 3)
        self.label = QtWidgets.QLabel(self.groupBox)
        self.label.setObjectName("label")
        self.gridLayout_5.addWidget(self.label, 0, 1, 1, 1)
        self.label_13 = QtWidgets.QLabel(self.groupBox)
        self.label_13.setObjectName("label_13")
        self.gridLayout_5.addWidget(self.label_13, 3, 1, 1, 1)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem)
        self.label_2 = QtWidgets.QLabel(self.groupBox)
        self.label_2.setObjectName("label_2")
        self.horizontalLayout_2.addWidget(self.label_2)
        self.label_size_spinBox = QtWidgets.QSpinBox(self.groupBox)
        self.label_size_spinBox.setMinimum(1)
        self.label_size_spinBox.setProperty("value", 15)
        self.label_size_spinBox.setObjectName("label_size_spinBox")
        self.horizontalLayout_2.addWidget(self.label_size_spinBox)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem1)
        self.gridLayout_5.addLayout(self.horizontalLayout_2, 0, 4, 2, 1)
        self.xlabel_lineEdit = QtWidgets.QLineEdit(self.groupBox)
        self.xlabel_lineEdit.setObjectName("xlabel_lineEdit")
        self.gridLayout_5.addWidget(self.xlabel_lineEdit, 0, 2, 1, 1)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem2)
        self.label_11 = QtWidgets.QLabel(self.groupBox)
        self.label_11.setObjectName("label_11")
        self.horizontalLayout.addWidget(self.label_11)
        self.ticks_size_spinBox = QtWidgets.QSpinBox(self.groupBox)
        self.ticks_size_spinBox.setMinimum(1)
        self.ticks_size_spinBox.setSingleStep(1)
        self.ticks_size_spinBox.setProperty("value", 15)
        self.ticks_size_spinBox.setObjectName("ticks_size_spinBox")
        self.horizontalLayout.addWidget(self.ticks_size_spinBox)
        spacerItem3 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem3)
        self.gridLayout_5.addLayout(self.horizontalLayout, 2, 4, 2, 1)
        self.label_7 = QtWidgets.QLabel(self.groupBox)
        self.label_7.setObjectName("label_7")
        self.gridLayout_5.addWidget(self.label_7, 2, 1, 1, 1)
        self.ylabel_lineEdit = QtWidgets.QLineEdit(self.groupBox)
        self.ylabel_lineEdit.setObjectName("ylabel_lineEdit")
        self.gridLayout_5.addWidget(self.ylabel_lineEdit, 1, 2, 1, 1)
        self.color_pallete = QtWidgets.QPushButton(self.groupBox)
        self.color_pallete.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.color_pallete.setStyleSheet("QPushButton{\n"
"            background-color: rgb(0, 0, 0);\n"
"            }")
        self.color_pallete.setText("")
        self.color_pallete.setObjectName("color_pallete")
        self.gridLayout_5.addWidget(self.color_pallete, 3, 2, 1, 1)
        self.cmap_label_lineEdit = QtWidgets.QLineEdit(self.groupBox)
        self.cmap_label_lineEdit.setObjectName("cmap_label_lineEdit")
        self.gridLayout_5.addWidget(self.cmap_label_lineEdit, 2, 2, 1, 1)
        self.formLayout = QtWidgets.QFormLayout()
        self.formLayout.setObjectName("formLayout")
        self.label_8 = QtWidgets.QLabel(self.groupBox)
        self.label_8.setObjectName("label_8")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_8)
        self.font_comboBox = QtWidgets.QComboBox(self.groupBox)
        self.font_comboBox.setObjectName("font_comboBox")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.font_comboBox)
        self.label_9 = QtWidgets.QLabel(self.groupBox)
        self.label_9.setObjectName("label_9")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_9)
        self.label_style_comboBox = QtWidgets.QComboBox(self.groupBox)
        self.label_style_comboBox.setObjectName("label_style_comboBox")
        self.label_style_comboBox.addItem("")
        self.label_style_comboBox.addItem("")
        self.label_style_comboBox.addItem("")
        self.label_style_comboBox.addItem("")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.label_style_comboBox)
        self.label_10 = QtWidgets.QLabel(self.groupBox)
        self.label_10.setObjectName("label_10")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.label_10)
        self.ticks_style_comboBox = QtWidgets.QComboBox(self.groupBox)
        self.ticks_style_comboBox.setObjectName("ticks_style_comboBox")
        self.ticks_style_comboBox.addItem("")
        self.ticks_style_comboBox.addItem("")
        self.ticks_style_comboBox.addItem("")
        self.ticks_style_comboBox.addItem("")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.ticks_style_comboBox)
        self.gridLayout_5.addLayout(self.formLayout, 0, 0, 4, 1)
        self.gridLayout_4.addWidget(self.groupBox, 2, 0, 1, 1)
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.gridLayout_4.addLayout(self.verticalLayout, 0, 0, 1, 1)
        spacerItem4 = QtWidgets.QSpacerItem(20, 10, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.gridLayout_4.addItem(spacerItem4, 1, 0, 1, 1)
        self.gridLayout.addWidget(self.frame, 0, 0, 1, 1)

        self.retranslateUi(Export_Figure)
        QtCore.QMetaObject.connectSlotsByName(Export_Figure)

    def retranslateUi(self, Export_Figure):
        _translate = QtCore.QCoreApplication.translate
        Export_Figure.setWindowTitle(_translate("Export_Figure", "Dialog"))
        self.groupBox.setTitle(_translate("Export_Figure", "Edit Figure"))
        self.label_6.setText(_translate("Export_Figure", "Y Label:"))
        self.save_fig_button.setText(_translate("Export_Figure", "Save Figure"))
        self.redraw_button.setText(_translate("Export_Figure", "Redraw Figure"))
        self.format_comboBox.setItemText(0, _translate("Export_Figure", "svg"))
        self.format_comboBox.setItemText(1, _translate("Export_Figure", "png"))
        self.format_comboBox.setItemText(2, _translate("Export_Figure", "jpeg"))
        self.format_comboBox.setItemText(3, _translate("Export_Figure", "tiff"))
        self.format_label.setText(_translate("Export_Figure", "Figure format:"))
        self.label_12.setText(_translate("Export_Figure", "Figure dpi:"))
        self.label_5.setText(_translate("Export_Figure", "Width (inches)"))
        self.label_4.setText(_translate("Export_Figure", "Figure Size:"))
        self.label_3.setText(_translate("Export_Figure", "Height (inches)"))
        self.label.setText(_translate("Export_Figure", "X Label:"))
        self.label_13.setText(_translate("Export_Figure", "Select Color:"))
        self.label_2.setText(_translate("Export_Figure", "Label Font Size:"))
        self.label_11.setText(_translate("Export_Figure", "Ticks Font Size:"))
        self.label_7.setText(_translate("Export_Figure", "Cmap Label:"))
        self.label_8.setText(_translate("Export_Figure", "Label/Ticks Font:"))
        self.label_9.setText(_translate("Export_Figure", "Label Style:"))
        self.label_style_comboBox.setItemText(0, _translate("Export_Figure", "normal"))
        self.label_style_comboBox.setItemText(1, _translate("Export_Figure", "italic"))
        self.label_style_comboBox.setItemText(2, _translate("Export_Figure", "oblique"))
        self.label_style_comboBox.setItemText(3, _translate("Export_Figure", "bold"))
        self.label_10.setText(_translate("Export_Figure", "Ticks Style:"))
        self.ticks_style_comboBox.setItemText(0, _translate("Export_Figure", "normal"))
        self.ticks_style_comboBox.setItemText(1, _translate("Export_Figure", "italic"))
        self.ticks_style_comboBox.setItemText(2, _translate("Export_Figure", "oblique"))
        self.ticks_style_comboBox.setItemText(3, _translate("Export_Figure", "bold"))
